@@ -1,4 +1,3 @@
-use super::Enarc;
 use std::{
     env, fs,
     path::{Path, PathBuf},
@@ -37,26 +36,14 @@ pub fn get_bin_or_cmd_name<'a>() -> &'a str {
 fn get_home_dir() -> Result<PathBuf, String> {
     let home_dir = dirs::home_dir();
     match home_dir {
-        None => Err("Não foi possivel localizar a pasta home do usuario.".into()),
+        None => Err("Não foi possível localizar a pasta home do usuário.".into()),
         Some(data) => Ok(data),
     }
 }
 
-fn read_enarc(path_mod: &mut PathBuf) -> Result<(), Box<dyn std::error::Error>> {
-    if let Ok(p) = check_and_get_enarc() {
-        let raw_enarc = fs::read_to_string(p)?;
-        let enarc = Enarc::from_string(raw_enarc)?;
-        *path_mod = PathBuf::from(enarc.ena_home_path);
-    }
-    Ok(())
-}
-
 pub fn create_or_get_ena_home_folder() -> Result<PathBuf, Box<dyn std::error::Error>> {
     let mut home_folder = get_home_dir()?;
 
-    if let Err(why) = read_enarc(&mut home_folder) {
-        println!("Ouve um erro ao ler o .enarc\n\nMotivo: {:?}", why);
-    }
     home_folder = home_folder.join(".ena-code");
     let path_ena_code_folder = Path::new(&home_folder);
     if !path_ena_code_folder.is_dir() {
@@ -64,15 +51,3 @@ pub fn create_or_get_ena_home_folder() -> Result<PathBuf, Box<dyn std::error::Er
     }
     Ok(home_folder)
 }
-
-fn check_and_get_enarc() -> Result<PathBuf, String> {
-    let home_dir = get_home_dir()?;
-    let enarc_file = home_dir.join(".enarc");
-
-    let path = Path::new(&enarc_file);
-    if path.is_file() {
-        Ok(enarc_file)
-    } else {
-        Err("O arquivo enarc não existe".into())
-    }
-}
